<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:fo="http://www.w3.org/1999/XSL/Format">

  <xsl:variable name="font">
	<xsl:value-of select="//AdHocReport/@font"/>
  </xsl:variable>

  <xsl:variable name="PageWidth">
	<xsl:value-of select="//AdHocReport/Pages/@Width"/>
  </xsl:variable>

  <xsl:variable name="MarginTop">
	<xsl:value-of select="10"/>
  </xsl:variable>

  <xsl:variable name="tivoliIMlogo">
	<xsl:value-of select="//AdHocReport/@tivoliIMlogo"/>
  </xsl:variable>

  <xsl:variable name="custlogo">
	<xsl:value-of select="//AdHocReport/ReportHeader/Logo"/>
  </xsl:variable>
  
   <xsl:variable name="pageNumberString">
  	<xsl:value-of select="//AdHocReport/ReportFooter"/>
  </xsl:variable>

  <xsl:variable name="tivoliIMbannerlogo">
	<xsl:value-of select="//AdHocReport/@tivoliIMbannerlogo"/>
  </xsl:variable>

  <!--Begin of C-TDC modification: New xsl variable  to indicat direction. -->
  <xsl:variable name="direction">
	<xsl:value-of select="//AdHocReport/@direction"/>
  </xsl:variable>
  <!--End of C-TDC modification-->
  

  <xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

	  <!-- defines the layout master -->
	  <fo:layout-master-set>
		<fo:simple-page-master master-name="first" margin-top="2.5cm" margin-bottom=".5cm" margin-left="2.5cm" margin-right="2.5cm">
			   <xsl:attribute name="page-width">
				 <xsl:value-of select="concat($PageWidth,'cm')"/>
			   </xsl:attribute>
		  <fo:region-before region-name="xsl-region-before-first" extent="5cm"/>
		  <fo:region-body margin-top="5cm" margin-bottom="2.50cm"/>
		  <fo:region-after extent="2cm"/>
		</fo:simple-page-master>
		<fo:simple-page-master master-name="rest" margin-top="2.5cm" margin-bottom=".5cm" margin-left="2.5cm" margin-right="2.5cm">
			   <xsl:attribute name="page-width">
				 <xsl:value-of select="concat($PageWidth,'cm')"/>
			   </xsl:attribute>
		  <fo:region-before region-name="xsl-region-before-rest" extent="5cm"/>
		  <fo:region-body margin-top="5cm" margin-bottom="2.50cm"/>
		  <fo:region-after extent="2cm"/>
		</fo:simple-page-master>
	<fo:page-sequence-master master-name="document">
	  <fo:repeatable-page-master-alternatives>
		  <fo:conditional-page-master-reference master-reference="first" page-position="first" />
		  <fo:conditional-page-master-reference master-reference="rest" page-position="rest" />
	  </fo:repeatable-page-master-alternatives>
	</fo:page-sequence-master>
	  </fo:layout-master-set>
	  <xsl:apply-templates select="AdHocReport/Pages/Page"/>

	</fo:root>
</xsl:template>


<!-- Template for the page layout. -->
<xsl:template match="//AdHocReport/Pages/Page">

  <!-- starts page layout -->
  <fo:page-sequence master-reference="document">
  

	<fo:static-content flow-name="xsl-region-before-first">


	<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:choose>
		<xsl:when test="//AdHocReport/ReportHeader/Logo">
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>

		<fo:table-body >
		<fo:table-row>

		<fo:table-cell>
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>

		<fo:table-cell>
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$custlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>
		</fo:table-row>
		</fo:table-body>
	</xsl:when>

	<xsl:otherwise>
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>	

		<fo:table-body >
		<fo:table-row>
	        <!--C-TDC modification (text-align attribute added) -->
		<xsl:if test="$direction='right'">
		<fo:table-cell text-align="center">  
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMbannerlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>
		</xsl:if>
		<xsl:if test="$direction='left'">
		<fo:table-cell text-align="left">  
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMbannerlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>
		</xsl:if>
		<!--End C-TDC modification--> 
		</fo:table-row>
		</fo:table-body>

	</xsl:otherwise>	
	</xsl:choose>
	
	</fo:table>

	  <fo:block font-size="20pt"
				font-family="{$font}"
		color="white"
		padding-top="3pt">
	  invisible line</fo:block>
	  <!--C-TDC modification (text-align attribute added)-->
	  <fo:block text-align="{$direction}" font-size="11pt"
		font-weight="bold"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
		<xsl:value-of select="../../ReportHeader/Title"/>
	  </fo:block>

	  <fo:block text-align="{$direction}" font-size="11pt"
		font-weight="Regular"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
		<xsl:value-of select="../../ReportHeader/Time"/>
	  </fo:block>

		<fo:block text-align="{$direction}" font-size="11pt"
		font-weight="Regular"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
		<xsl:value-of select="../../ReportHeader/Author"/>
		</fo:block>

	</fo:static-content>


	<fo:static-content flow-name="xsl-region-before-rest">


	<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:choose>
		<xsl:when test="//AdHocReport/ReportHeader/Logo">
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>

		<fo:table-body >
		<fo:table-row>

		<fo:table-cell>
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>

		<fo:table-cell>
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$custlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>

		</fo:table-row>
		</fo:table-body>
	</xsl:when>

	<xsl:otherwise>
		<fo:table-column>
		  <xsl:attribute name="column-width">
			<xsl:value-of select="concat($PageWidth,'cm')"/>
		  </xsl:attribute>
		</fo:table-column>	

		<fo:table-body >
		<fo:table-row>
        
        <!--C-TDC modification (text-align attribute added)-->
		<xsl:if test="$direction='right'">
		<fo:table-cell text-align="center">  
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMbannerlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>
		</xsl:if>
		<xsl:if test="$direction='left'">
		<fo:table-cell text-align="left">  
		<fo:block>
			<fo:external-graphic height="auto" width="auto" src="{$tivoliIMbannerlogo}">
			</fo:external-graphic>
		</fo:block>
		</fo:table-cell>
		</xsl:if>
		</fo:table-row>
		</fo:table-body>

	</xsl:otherwise>	
	</xsl:choose>
	</fo:table>

        <fo:block font-size="20pt"
				font-family="{$font}"
		color="white"
		padding-top="3pt">
	  invisible line</fo:block>
	  
	  <!--C-TDC modification (text-align attribute added)-->
	  <fo:block text-align="{$direction}" 	font-size="10pt"
		font-weight="bold"
				font-family="{$font}"
		color="black"
		padding-top="3pt">
		<xsl:value-of select="../../ReportHeader/Title"/>
	  </fo:block>
	</fo:static-content>


	<fo:static-content flow-name="xsl-region-after">
	<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<fo:table-column>
	  <xsl:attribute name="column-width">
	    <!--Begin of C-TDC modification: 4 insted of 2 -->
	    <xsl:if test="$direction='right'">
		     <xsl:value-of select="concat($PageWidth div 4,'cm')"/>
		</xsl:if>
	    <xsl:if test="$direction='left'">
		     <xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		</xsl:if>
	  </xsl:attribute>
	</fo:table-column>
	<fo:table-column>
	  <xsl:attribute name="column-width">
		<xsl:value-of select="concat($PageWidth div 4,'cm')"/>
	  </xsl:attribute>
	</fo:table-column>
	<fo:table-column>
	  <xsl:attribute name="column-width">
	    <!--Begin of C-TDC modification: 2 insted of 4 -->
	    <xsl:if test="$direction='right'">
		     <xsl:value-of select="concat($PageWidth div 2,'cm')"/>
		</xsl:if>
	    <xsl:if test="$direction='left'">
		     <xsl:value-of select="concat($PageWidth div 4,'cm')"/>
		</xsl:if>
		
	  </xsl:attribute>
	</fo:table-column>
	<fo:table-body font-size="10pt" font-family="{$font}" >
	<fo:table-row>
    <!--Begin of C-TDC modification (table cells are inversed)-->
	<xsl:if test="$direction='right'">    
    <!-- This was the 3rd. -->
	<fo:table-cell>
	  <fo:block
				font-size="9pt"
				font-family="{$font}"
				line-height="14pt"
				padding-top="5pt" wrap-option="wrap" hyphenate="true">
		<fo:page-number/><xsl:value-of select="$pageNumberString"/><fo:page-number-citation ref-id="last-page"/>
	  </fo:block>
	</fo:table-cell>
	<!-- This was th second.-->
	<fo:table-cell>
	 <fo:block>
	 </fo:block>
	</fo:table-cell>
	<!-- This was the 1st-->
	<xsl:apply-templates select="copyright"/>
    </xsl:if>
    <xsl:if test="$direction='left'">
    	  <xsl:apply-templates select="copyright"/>
	<fo:table-cell>
	<fo:block>
	</fo:block>
	</fo:table-cell>
	<fo:table-cell>
	  <fo:block
				font-size="9pt"
				font-family="{$font}"
				line-height="14pt"
				padding-top="5pt" wrap-option="wrap" hyphenate="true">
		<fo:page-number/><xsl:value-of select="$pageNumberString"/><fo:page-number-citation ref-id="last-page"/>
	  </fo:block>
	</fo:table-cell>
    </xsl:if>
    <!--End of C-TDC modification-->
    
	</fo:table-row>
	</fo:table-body>
	</fo:table>
	</fo:static-content>
	<fo:flow flow-name="xsl-region-body">
	   <xsl:apply-templates select="Body"/>
		<fo:block id="last-page"/>
	</fo:flow>
  </fo:page-sequence>
</xsl:template>

<xsl:template match="copyright">
	<fo:table-cell>
	  <fo:block
				font-size="8pt"
				font-family="{$font}"
				line-height="14pt"
				padding-top="5pt" wrap-option="wrap" hyphenate="true">
	   <xsl:apply-templates/>
	  </fo:block>
	</fo:table-cell>
</xsl:template>

<xsl:template match="Body">
	  <fo:block font-size="14pt"
				font-family="{$font}"
		color="white"
		padding-top="3pt">
	  invisible line</fo:block>
	  <!--Begin of C-TDC modification (text-align attribute added)-->
	  <fo:block font-size="10pt" text-align="{$direction}"
		font-weight="bold"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
		<xsl:value-of select="@reportCriteria"/>
	  </fo:block>
	<!-- Begin of report criteria table -->
	<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!--Begin of C-TDC modification-->
	<xsl:if test="$direction='right'">
	 <fo:table-column/>
	</xsl:if>
    <!--End of C-TDC modification-->
	<fo:table-column>
	  <xsl:attribute name="column-width">
		<xsl:value-of select="concat($PageWidth div 2.5,'cm')"/>
	  </xsl:attribute>
	</fo:table-column>
	<fo:table-column>
	  <xsl:attribute name="column-width">
		<xsl:value-of select="concat($PageWidth div 2.5,'cm')"/>
	  </xsl:attribute>
	</fo:table-column>
	<fo:table-body font-size="10pt" font-family="{$font}">
	<fo:table-row>
	<!--Begin of C-TDC modification-->
	<xsl:if test="$direction='right'">
	<fo:table-cell/>
	</xsl:if>
	<!--End of C-TDC modification-->
	<!--Begin of C-TDC modification: Order of cells is inverted. -->
	
	<!--C-TDC modification: text-align attribute added-->
	<xsl:if test="$direction='right'">
	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@datePrintedValue"/>
	  </fo:block>
	</fo:table-cell>
	<!--C-TDC modification: text-align attribute added-->
	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@datePrinted"/></fo:block>
	</fo:table-cell>
	</xsl:if>
	<xsl:if test="$direction='left'">
		<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@datePrinted"/></fo:block>
	</fo:table-cell>
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">

	  <xsl:value-of select="@datePrintedValue"/>
	  </fo:block>
	</fo:table-cell>
	</xsl:if>
	<!--End of C-TDC modification-->
	</fo:table-row>
	<fo:table-row>
	
	<!--Begin of C-TDC modification-->
	<xsl:if test="$direction='right'">
	<fo:table-cell/>
	</xsl:if>
	<!--End of C-TDC modification-->
	
	<!--Begin of C-TDC modification: Order of cells is inverted. -->
	<xsl:if test="$direction='right'">
	<!--C-TDC modification: text-align attribute added-->
	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">

	  <xsl:value-of select="@timePrintedValue"/>
	  </fo:block>
	</fo:table-cell>
	<!--C-TDC modification: text-align attribute added-->
	<fo:table-cell text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@timePrinted"/></fo:block>
	</fo:table-cell>
	</xsl:if>
	<xsl:if test="$direction='left'">
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@timePrinted"/></fo:block>
	</fo:table-cell>
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">

	  <xsl:value-of select="@timePrintedValue"/>
	  </fo:block>
	</fo:table-cell>
	</xsl:if>
	<!--End of C-TDC modification-->
	</fo:table-row>
	<fo:table-row>
	<!--Begin of C-TDC modification-->
	<xsl:if test="$direction='right'">
	<fo:table-cell/>
	</xsl:if>
	<!--End of C-TDC modification-->

    <!--Begin of C-TDC modification: inverting columns-->
    <xsl:if test="$direction='right'">
	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">

	  <xsl:value-of select="@timeZoneValue"/>
	  </fo:block>
	</fo:table-cell>
	    <!--C-TDC modification: text-align attribute added-->
		<fo:table-cell text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@timeZone"/></fo:block>
	</fo:table-cell>
	</xsl:if >
	<xsl:if test="$direction='left'">
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@timeZone"/></fo:block>
	</fo:table-cell>
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">

	  <xsl:value-of select="@timeZoneValue"/>
	  </fo:block>
	</fo:table-cell>
	</xsl:if >
	<!--End of C-TDC modification-->	
	</fo:table-row>
	
	<xsl:for-each select="UserInput">
	<fo:table-row>
	<!--Begin of C-TDC modification-->
	<xsl:if test="$direction='right'">
	<fo:table-cell/>
	</xsl:if >
	<!--End of C-TDC modification-->
	
	<!--Begin of C-TDC modification: inverse the following cells-->
	<xsl:if test="$direction='right'">
	<!--C-TDC modification: text-align attribute added-->
 	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="."/>
	  </fo:block>
	</fo:table-cell>	
	<!--C-TDC modification: text-align attribute added-->
 	<fo:table-cell  text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@userInput"/></fo:block>
	</fo:table-cell>
	</xsl:if >
	<xsl:if test="$direction='left'">
		<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block font-size="10pt"
				font-family="{$font}"
		color="black"
		padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="@userInput"/></fo:block>
	</fo:table-cell>
	<fo:table-cell  border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
	  <fo:block xmlns:java="http://xml.apache.org/xslt/java" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="."/>
	  </fo:block>
	</fo:table-cell>
	</xsl:if >
	<!--End of C-TDC modification-->
	</fo:table-row>
	</xsl:for-each>
	</fo:table-body>
	</fo:table>
	<!-- End of report criteria table -->
	  <fo:block font-size="6pt"
				font-family="{$font}"
		color="white"
		padding-top="3pt">
	  invisible line</fo:block>

	  <fo:block font-size="14pt"
				font-family="{$font}"
		color="white"
		padding-top="3pt">
	  invisible line</fo:block>
	  <xsl:apply-templates select="ColumnTable | RowTable"/>
</xsl:template>

<!-- RowTable is a table which has each row indicating a specific topic. Eg. Last Reconcilaition Summary-->
<xsl:template match="RowTable">
<xsl:choose>
<xsl:when test="@NumberOfRows='0'">
</xsl:when>
<xsl:otherwise>
<!--C-TDC modification (text-align attribute added)-->
<fo:block 
    text-align="{$direction}"
    font-size="10pt"
	font-weight="bold"
		font-family="{$font}"
	color="black"
	padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="./Title"/>
</fo:block>

<xsl:variable name="Col1Width"><xsl:value-of select="@Col1Width"/></xsl:variable>
<xsl:variable name="Col2Width"><xsl:value-of select="@Col2Width"/></xsl:variable>
<fo:block>
  <fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format" table-omit-header-at-break="false">
  	<!--Begin of C-TDC modification-->
  	<xsl:if test="$direction='right'" >
	<fo:table-column/>
	</xsl:if>
	<!--End of C-TDC modification-->

	<fo:table-column>
		<xsl:attribute name="column-width">
		  <xsl:value-of select="concat($Col1Width,'cm')"/>
		</xsl:attribute>
	</fo:table-column>
	<fo:table-column>
		<xsl:attribute name="column-width">
		  <xsl:value-of select="concat($Col2Width,'cm')"/>
		</xsl:attribute>
	</fo:table-column>

	
	<fo:table-body font-size="10pt" font-family="{$font}">
	  <xsl:for-each select="./r">
	  <fo:table-row line-height="12pt">
	  	  <!--Begin of C-TDC modification-->
	  	  <xsl:if test="$direction='right'" >
		  <fo:table-cell/>
		  </xsl:if>
		  <!--End of C-TDC modification-->
			
	  	  <!--Begin of C-TDC modification: Cells are mirrored -->
	  	  <xsl:if test="$direction='right'" >
		  <fo:table-cell>
            <!--Begin of C-TDC modification: change start to right-->
			<fo:block text-align="{$direction}">
				<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format" table-omit-header-at-break="false">
					<fo:table-column>
						<xsl:attribute name="column-width">
						<xsl:value-of select="concat($Col2Width,'cm')"/>
						</xsl:attribute>
					</fo:table-column>
					<fo:table-body font-size="10pt" font-family="{$font}">
					  <xsl:for-each select="./RowValue">
					  <fo:table-row line-height="12pt">
						  <fo:table-cell border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
							border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
							border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
							border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
						display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
						    <!--Begin of C-TDC modification: changing start to right-->
							<fo:block text-align="{$direction}" wrap-option="wrap" hyphenate="true">
							  <xsl:value-of select="."/>
							</fo:block>
						  </fo:table-cell>
					  </fo:table-row>
					  </xsl:for-each>
					</fo:table-body>
				</fo:table>
			</fo:block>
		  </fo:table-cell>
		  <!-- text-align attribute added-->
		  <fo:table-cell text-align="{$direction}" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
			<fo:block text-align="{$direction}" font-weight="bold" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="./RowHeading"/>
			</fo:block>
		  </fo:table-cell>
	  </xsl:if>
	  <xsl:if test="$direction='left'">
		  <fo:table-cell border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		    display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
			<fo:block text-align="start" font-weight="bold" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="./RowHeading"/>
			</fo:block>
		  </fo:table-cell>
		  <fo:table-cell>
			<fo:block text-align="start">
				<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format" table-omit-header-at-break="false">
					<fo:table-column>
						<xsl:attribute name="column-width">
						<xsl:value-of select="concat($Col2Width,'cm')"/>
						</xsl:attribute>
					</fo:table-column>
					<fo:table-body font-size="10pt" font-family="{$font}">
					  <xsl:for-each select="./RowValue">
					  <fo:table-row line-height="12pt">
						  <fo:table-cell border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
							border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
							border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
							border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
						display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt">
							<fo:block text-align="start" wrap-option="wrap" hyphenate="true">
							  <xsl:value-of select="."/>
							</fo:block>
						  </fo:table-cell>
					  </fo:table-row>
					  </xsl:for-each>
					</fo:table-body>
				</fo:table>
			</fo:block>
		  </fo:table-cell>
	  </xsl:if>
      <!--End of C-TDC modification-->
	  </fo:table-row>
	  </xsl:for-each>
	</fo:table-body>
  </fo:table>
</fo:block>
<fo:block font-size="6pt"
	font-family="{$font}"
	color="white"
	padding-top="3pt">
  invisible line
</fo:block>

<fo:block font-size="14pt"
	font-family="{$font}"
	color="white"
	padding-top="3pt">
  invisible line
</fo:block>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- ColumnTable is a table which has each column indicating a specific topic. Eg. Modified Accounts List-->
<xsl:template match="ColumnTable">
<xsl:choose>
<xsl:when test="@NumberOfRows='0'">
<fo:block text-align="center">
			  <xsl:value-of select="."/>
</fo:block>
</xsl:when>
<xsl:when test="@NumberOfRows='-1'">
<fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format">
<fo:table-column>
  <xsl:attribute name="column-width">
	<xsl:value-of select="concat($PageWidth,'cm')"/>
  </xsl:attribute>
</fo:table-column>
<fo:table-body font-size="10pt" font-family="{$font}" >
<fo:table-row>
<fo:table-cell>
<fo:block text-align="center">
			  <xsl:value-of select="."/>
</fo:block>
</fo:table-cell>
</fo:table-row>
</fo:table-body>
</fo:table>
</xsl:when>
<xsl:otherwise>
<!--C-TDC modification (text-align attribute added)-->
<fo:block font-size="10pt"
    text-align="{$direction}"
	font-weight="bold"
	font-family="{$font}"
	color="black"
	padding-top="3pt" wrap-option="wrap" hyphenate="true">
	  <xsl:value-of select="./Title"/>
</fo:block>

<fo:block>
  <fo:table  xmlns:fo="http://www.w3.org/1999/XSL/Format" table-omit-header-at-break="false">
  <!--Begin of C-TDC modifications-->
  <xsl:if test="$direction='right'">
	<fo:table-header>
		  <fo:table-row line-height="12pt">
		      <!--New Cell Added-->
		      <fo:table-cell/>
			  <xsl:for-each select="./ColumnLabel">
			  <!--inverse the cells order-->
			  <xsl:sort select="position()" order="descending"/>
			  <fo:table-cell text-align="right" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt"
		font-weight="bold" font-family="{$font}" font-size="10pt">
				<fo:block text-align="right" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="."/>
				</fo:block>
			  </fo:table-cell>
			</xsl:for-each>
		  </fo:table-row>
	  </fo:table-header>
	  <!--New column added-->
	  <fo:table-column/>
	  <xsl:for-each select="./ColumnLabel">
      <!--inverse the cells order-->
	  <xsl:sort select="position()" order="descending"/>
	  <xsl:variable name="Width"><xsl:value-of select="@Width"/></xsl:variable>
	  <fo:table-column>
		<xsl:attribute name="column-width">
		  <xsl:value-of select="concat($Width,'cm')"/>
		</xsl:attribute>
	  </fo:table-column>
	</xsl:for-each>
	<fo:table-body font-size="10pt" font-family="{$font}">
	  <xsl:for-each select="./r">
	  <fo:table-row line-height="12pt" keep-together="always">
	  	<!--Begin of C-TDC modification-->
		<fo:table-cell/>
		<!--End of C-TDC modification-->
		<xsl:for-each select="./cv">
		  <!--C-TDC modification (text-align attribute added)-->
		  <fo:table-cell text-align="right" border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt"
		font-family="{$font}" font-size="10pt">
			<fo:block text-align="right" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="."/>
			</fo:block>
		  </fo:table-cell>
		</xsl:for-each>
	  </fo:table-row>
	  </xsl:for-each>
	</fo:table-body>
  </xsl:if>
  <!--Left ColumnTable implementations -->
  <xsl:if test="$direction='left'">
  	<fo:table-header>
		  <fo:table-row line-height="12pt">
			  <xsl:for-each select="./ColumnLabel">
			  <fo:table-cell border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt"
		font-weight="bold" font-family="{$font}" font-size="10pt">
				<fo:block text-align="start" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="."/>
				</fo:block>
			  </fo:table-cell>
			</xsl:for-each>
		  </fo:table-row>
	  </fo:table-header>
	  <xsl:for-each select="./ColumnLabel">
	  <xsl:variable name="Width"><xsl:value-of select="@Width"/></xsl:variable>
	  <fo:table-column>
		<xsl:attribute name="column-width">
		  <xsl:value-of select="concat($Width,'cm')"/>
		</xsl:attribute>
	  </fo:table-column>
	</xsl:for-each>
	<fo:table-body font-size="10pt" font-family="{$font}">
	  <xsl:for-each select="./r">
	  <fo:table-row line-height="12pt" keep-together="always">
		<xsl:for-each select="./cv">
		  <fo:table-cell border-left-color="black" border-left-width="0.25pt" border-left-style="solid"
			border-top-color="black" border-top-width="0.25pt" border-top-style="solid"
			border-right-color="black" border-right-width="0.25pt" border-right-style="solid"
			border-bottom-color="black" border-bottom-width="0.25pt" border-bottom-style="solid"
		display-align="center" padding-left="5pt" padding-right="5pt" padding-top="5pt" padding-bottom="5pt"
		font-family="{$font}" font-size="10pt">
			<fo:block text-align="start" wrap-option="wrap" hyphenate="true">
			  <xsl:value-of select="."/>
			</fo:block>
		  </fo:table-cell>
		</xsl:for-each>
	  </fo:table-row>
	  </xsl:for-each>
	</fo:table-body>
    </xsl:if>
  <!--End of C-TDC modification -->
  </fo:table>
</fo:block>
<fo:block font-size="6pt"
	font-family="{$font}"
	color="white"
	padding-top="3pt">
  invisible line
</fo:block>

<fo:block font-size="14pt"
	font-family="{$font}"
	color="white"
	padding-top="3pt">
  invisible line
</fo:block>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

</xsl:stylesheet>

